@@ -24,6 +24,10 @@
 #ifndef LINGOTI18N_H_
 #define LINGOTI18N_H_
 
+#include <libintl.h>
+#include <locale.h>
+#include <langinfo.h>
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
